<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Vytvoriť tabuľku</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Vytvoriť novú tabuľku</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Zarovnať nadol</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Zarovnanie obsahu vybraných buniek nadol</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Zarovnať na stred</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Zarovnanie obsahu vybraných buniek na stred</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Zarovnať doľava</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Zarovnanie obsahu vybraných buniek doľava</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Zarovnať doprava</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Zarovnanie obsahu vybraných buniek doprava</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Zarovnať nahor</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Zarovnanie obsahu vybraných buniek nahor</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Vertikálne zarovnanie na stred</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation>Vertikálne zarovnať na stred obsah vybraných buniek</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Exportovať tabuľku</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Export tabuľku do súboru CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importovať tabuľku</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Import CSV súboru do tabuľky</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Zlúčiť bunky</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation>Zlúčiť vybrané bunky</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Nastaviť pomenovanie</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Nastaviť pomenovanie pre vybranú bunku</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Rozdeliť bunku</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation>Rozdeliť predtým zlúčené bunky</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Tučné písmo</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation>Nastaviť text vo vybraných bunkách na tučný</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Kurzívny text</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation>Nastaviť text vo vybraných bunkách na kurzívu</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Podčiarknuť text</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation>Podčiarknúť text vo vybraných bunkách</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation>Vlastná farba</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>Zlúčiť bunky</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Rozdeliť bunku</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation type="unfinished">Left-align cell</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation type="unfinished">Center cell</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation type="unfinished">Right-align cell</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation type="unfinished">Top-align cell</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation type="unfinished">Bottom-align cell</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation type="unfinished">Vertically center cells</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation type="unfinished">Set bold text</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation type="unfinished">Set italic text</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation type="unfinished">Set underline text</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation type="unfinished">Create Spreadsheet</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation type="unfinished">Set cell properties</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation type="unfinished">Edit cell</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>Vložiť riadky</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Odstrániť riadky</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Vložiť stĺpce</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation type="unfinished">Clear cell(s)</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation type="unfinished">Set foreground color</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation type="unfinished">Set background color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Vlastnosti bunky</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Farba</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Text</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Pozadie</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Zarovnanie</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>Horizontálne</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Vľavo</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Stred</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Vpravo</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>Zvislý</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Zhora</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Spodok</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Štýl</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Tučné</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Kurzíva</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Podčiarknutie</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Zobrazovaná jednotka</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Text jednotky, napr. "mm", ktorý sa automaticky zapíše po zadanej číselnej hodnote</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>P&amp;omenovanie</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Pomenovanie pre túto bunku</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Všetko (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importovať súbor</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Exportovať súbor</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Zobraziť tabuľku</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Nastaviť farbu popredia bunky</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Nataviť farbu popredia buniek zošita</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Nataviť farbu pozadia bunky</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Nastaviť farbu pozadia buniek zošita</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation>Tabuľkový procesor nepodporuje vyberanie rozsahu pri vkladaní.
Prosím vyberte len jednu bunku.</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation>Kopírovať a vložiť zlyhalo</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation>Adresa obsahuje neplatné znaky.</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Odkazovať na bunku jej pomenovaním, napríklad
Spreadsheet.moje_pomenovanie namiesto Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Čierna</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Biela</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Červená</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Tmavo červená</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Zelená</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Tmavo zelená</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Modrá</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Tmavo modrá</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Azúrová</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Tmavo modrá</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Purpurová</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Tmavo purpurová</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Žltá</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Tmavo žltá</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Sivá</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Tmavo sivá</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Svetlo sivá</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation>Vlastná farba</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Forma</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation>&amp;Obsah:</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation>&amp;Pomenovanie:</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Odkazovať na bunku jej pomenovaním, napríklad
Spreadsheet.moje_pomenovanie namiesto Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Nepomenovaný</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Vložiť riadky</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Odstrániť riadky</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Vložiť stĺpce</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Odstrániť stĺpce</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Vlastnosti...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tabuľka</translation>
    </message>
  </context>
</TS>
